@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Iterable
+from typing import List
 
 try:
     import pkg_resources
@@ -20,4 +20,4 @@ try:
 except ImportError:
     import pkgutil
 
-    __path__: Iterable[str] = pkgutil.extend_path(__path__, __name__)
+    __path__: List[str] = pkgutil.extend_path(__path__, __name__)
